Simulation of the Galton Bean Machine, which was an old physical machine that demonstrated the normal distribution. https://en.wikipedia.org/wiki/Bean_machine

It takes two arguments, the number of beans and the height of the machine::

  --size=10000*100

